bottom_navigation_spotlight library

Classes

BottomNavigationSpotlight
SpotlightItem
Represents a single spotlight destination in the navigation bar. Each item can be highlighted with a spotlight effect when selected.