menu
bottom_navigation_spotlight package
documentation
bottom_navigation_spotlight.dart
bottom_navigation_spotlight.dart
dark_mode
light_mode
bottom_navigation_spotlight
library
Classes
BottomNavigationSpotlight
SpotlightItem
Represents a single spotlight destination in the navigation bar. Each item can be highlighted with a spotlight effect when selected.
bottom_navigation_spotlight package
documentation
bottom_navigation_spotlight.dart
bottom_navigation_spotlight
package
Libraries
bottom_navigation_spotlight
bottom_navigation_spotlight library